module.exports = defineTest({
	description: 'make sure re-declarations via var and function are linked properly'
});
